@@ -397,7 +397,9 @@ public class StartVmBackupCommand<T extends VmBackupParameters> extends VmComman
     private void finalizeVmBackup() {
         cleanDisksBackupModeIfSupported();
         unlockDisks();
-        if (isLiveBackup()) {
+        // Scratch disks removal should occur even if the VM is in 'PAUSED' state,
+        // the VM can enter to 'PAUSED' state during the backup due to storage space issues etc..
+        if (getVm().getStatus().isUpOrPaused()) {
             removeScratchDisks();
         }
     }
@@ -657,19 +659,13 @@ public class StartVmBackupCommand<T extends VmBackupParameters> extends VmComman
         return permissionList;
     }
 
-    @Override
-    protected Map<String, Pair<String, String>> getSharedLocks() {
-        Map<String, Pair<String, String>> locks = new HashMap<>();
-        locks.put(getParameters().getVmBackup().getVmId().toString(),
-                    LockMessagesMatchUtil.makeLockingPair(LockingGroup.VM, EngineMessage.ACTION_TYPE_FAILED_VM_IS_LOCKED));
-        return locks;
-    }
-
     @Override
     protected Map<String, Pair<String, String>> getExclusiveLocks() {
         Map<String, Pair<String, String>> locks = new HashMap<>();
         getDiskIds().forEach(id -> locks.put(id.toString(),
                         LockMessagesMatchUtil.makeLockingPair(LockingGroup.DISK, EngineMessage.ACTION_TYPE_FAILED_DISK_IS_LOCKED)));
+        locks.put(getParameters().getVmBackup().getVmId().toString(),
+                LockMessagesMatchUtil.makeLockingPair(LockingGroup.VM, EngineMessage.ACTION_TYPE_FAILED_VM_IS_DURING_BACKUP));
         return locks;
     }
 
